import os
import requests
import json


def is_human(captcha_response: dict, secret: str = os.environ['CAPTCHA_SECRET_KEY']):
    """
    Validating recaptcha response from google server
    Returns True captcha test passed for submitted form else returns False.
    """
    payload = {'response': captcha_response, 'secret': secret}
    response = requests.post("https://www.google.com/recaptcha/api/siteverify",
                             payload)
    response_text = json.loads(response.text)
    return response_text['success']



import time
import os


def write(string: str, delay: float = 0.06):
    """Print text to the console as if it was being typed. """
    for i in str(string):
        print(i, end="", flush=True)
        time.sleep(delay)
    print()



import os
import smtplib
from email.message import EmailMessage


class Email:
    """Connect to SMTP server and send emails"""

    def __init__(self, recipient: str, sender: str, password: str = os.environ['PASSWORD'], server: str = 'smtp.yandex.com', port: int = 465):
        """
        Connect to SMTP server and set variables for Email class
        """
        self.recipient = recipient
        self.sender = sender
        self.server = smtplib.SMTP_SSL(server, port)
        self.server.login(self.sender, password)
        print('Connected')

    def sendEmail(self, subject, message):
        """Send an email using variables in self"""
        email = f'Name: {self.name}\nEmail: {self.email}\nSubject: {self.subject}\nMessage: {message}'
        msg = EmailMessage()
        msg.set_content(email)
        msg['Subject'] = subject
        msg['From'] = self.sender
        msg['To'] = self.recipient
        try:
            self.server.send_message(msg)
            print('Email successfully sent')
            return True
        except Exception as e:
            print(e)
            return False



import os


def clear():
    """Clear the console"""
    # Check if Operating System is Mac and Linux or Windows
    if os.name == 'posix':
        # If OS is macOS or Linux
        _ = os.system('clear')
    else:
        # Else Operating System is Windows (os.name = nt)
        _ = os.system('cls')
